Update copyright notices and docs
Change-Id: Idee9b24f42e41f85a68f64ceab5f14d525442e2e
diff --git a/core/auditor.cpp b/core/auditor.cpp
index 34f85d0..b2db2b7 100644
--- a/core/auditor.cpp
+++ b/core/auditor.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "auditor.hpp"
diff --git a/core/conf/checker.cpp b/core/conf/checker.cpp
index 8c63458..d00bb34 100644
--- a/core/conf/checker.cpp
+++ b/core/conf/checker.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "checker.hpp"
diff --git a/core/conf/checker.hpp b/core/conf/checker.hpp
index bc253f3..17117aa 100644
--- a/core/conf/checker.hpp
+++ b/core/conf/checker.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CONF_CHECKER_HPP
-#define NSL_CONF_CHECKER_HPP
+#ifndef NDN_DELOREAN_CONF_CHECKER_HPP
+#define NDN_DELOREAN_CONF_CHECKER_HPP
#include "common.hpp"
#include "config.hpp"
@@ -95,4 +95,4 @@
} // namespace conf
} // namespace nsl
-#endif // NSL_CONF_CHECKER_HPP
+#endif // NDN_DELOREAN_CONF_CHECKER_HPP
diff --git a/core/conf/config-file.cpp b/core/conf/config-file.cpp
index c25018c..ffb8051 100644
--- a/core/conf/config-file.cpp
+++ b/core/conf/config-file.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "config-file.hpp"
diff --git a/core/conf/config-file.hpp b/core/conf/config-file.hpp
index 882fbab..e86def2 100644
--- a/core/conf/config-file.hpp
+++ b/core/conf/config-file.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CONF_CONFIG_FILE_HPP
-#define NSL_CONF_CONFIG_FILE_HPP
+#ifndef NDN_DELOREAN_CONF_CONFIG_FILE_HPP
+#define NDN_DELOREAN_CONF_CONFIG_FILE_HPP
#include "common.hpp"
#include "config.hpp"
@@ -76,4 +76,4 @@
} // namespace conf
} // namespace nsl
-#endif // NSL_CONF_CONFIG_FILE_HPP
+#endif // NDN_DELOREAN_CONF_CONFIG_FILE_HPP
diff --git a/core/conf/config.hpp b/core/conf/config.hpp
index ec3d5f5..7bffe63 100644
--- a/core/conf/config.hpp
+++ b/core/conf/config.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CONF_CONFIG_HPP
-#define NSL_CONF_CONFIG_HPP
+#ifndef NDN_DELOREAN_CONF_CONFIG_HPP
+#define NDN_DELOREAN_CONF_CONFIG_HPP
#include <boost/property_tree/ptree.hpp>
@@ -42,4 +42,4 @@
} // namespace conf
} // namespace nsl
-#endif // NSL_CONF_CONFIG_HPP
+#endif // NDN_DELOREAN_CONF_CONFIG_HPP
diff --git a/core/conf/filter.cpp b/core/conf/filter.cpp
index 6838d92..7f4c945 100644
--- a/core/conf/filter.cpp
+++ b/core/conf/filter.cpp
@@ -1,25 +1,24 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-
#include "filter.hpp"
#include <boost/algorithm/string.hpp>
diff --git a/core/conf/filter.hpp b/core/conf/filter.hpp
index fe399f5..65a58ce 100644
--- a/core/conf/filter.hpp
+++ b/core/conf/filter.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CONF_FILTER_HPP
-#define NSL_CONF_FILTER_HPP
+#ifndef NDN_DELOREAN_CONF_FILTER_HPP
+#define NDN_DELOREAN_CONF_FILTER_HPP
#include "common.hpp"
#include "config.hpp"
@@ -107,4 +107,4 @@
} // namespace conf
} // namespace ndn
-#endif // NSL_CONF_FILTER_HPP
+#endif // NDN_DELOREAN_CONF_FILTER_HPP
diff --git a/core/conf/key-locator-checker.cpp b/core/conf/key-locator-checker.cpp
index 2fd27bc..8e21677 100644
--- a/core/conf/key-locator-checker.cpp
+++ b/core/conf/key-locator-checker.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "key-locator-checker.hpp"
diff --git a/core/conf/key-locator-checker.hpp b/core/conf/key-locator-checker.hpp
index 921faa2..97f270b 100644
--- a/core/conf/key-locator-checker.hpp
+++ b/core/conf/key-locator-checker.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CONF_KEY_LOCATOR_CHECKER_HPP
-#define NSL_CONF_KEY_LOCATOR_CHECKER_HPP
+#ifndef NDN_DELOREAN_CONF_KEY_LOCATOR_CHECKER_HPP
+#define NDN_DELOREAN_CONF_KEY_LOCATOR_CHECKER_HPP
#include "common.hpp"
#include "config.hpp"
@@ -124,4 +124,4 @@
} // namespace conf
} // namespace nsl
-#endif // NSL_CONF_KEY_LOCATOR_CHECKER_HPP
+#endif // NDN_DELOREAN_CONF_KEY_LOCATOR_CHECKER_HPP
diff --git a/core/conf/rule.cpp b/core/conf/rule.cpp
index a4b571f..55dc59d 100644
--- a/core/conf/rule.cpp
+++ b/core/conf/rule.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "rule.hpp"
diff --git a/core/conf/rule.hpp b/core/conf/rule.hpp
index 5ec229f..47a70fd 100644
--- a/core/conf/rule.hpp
+++ b/core/conf/rule.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CONF_RULE_HPP
-#define NSL_CONF_RULE_HPP
+#ifndef NDN_DELOREAN_CONF_RULE_HPP
+#define NDN_DELOREAN_CONF_RULE_HPP
#include "filter.hpp"
#include "checker.hpp"
@@ -70,4 +70,4 @@
} // namespace conf
} // namespace nsl
-#endif // NSL_CONF_RULE_HPP
+#endif // NDN_DELOREAN_CONF_RULE_HPP
diff --git a/core/db.cpp b/core/db.cpp
index 22361c5..22474df 100644
--- a/core/db.cpp
+++ b/core/db.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "db.hpp"
@@ -106,7 +106,7 @@
// Open database
int result = sqlite3_open_v2((dir / "sig-logger.db").c_str(), &m_db,
SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE,
-#ifdef NSL_DISABLE_SQLITE3_FS_LOCKING
+#ifdef NDN_DELOREAN_DISABLE_SQLITE3_FS_LOCKING
"unix-dotfile"
#else
nullptr
diff --git a/core/leaf.cpp b/core/leaf.cpp
index e862d37..a35d489 100644
--- a/core/leaf.cpp
+++ b/core/leaf.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "leaf.hpp"
diff --git a/core/logger-response.cpp b/core/logger-response.cpp
index cef7e64..bb796ad 100644
--- a/core/logger-response.cpp
+++ b/core/logger-response.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "logger-response.hpp"
diff --git a/core/logger-response.hpp b/core/logger-response.hpp
index 8a393e4..d773ab2 100644
--- a/core/logger-response.hpp
+++ b/core/logger-response.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_LOGGER_RESPONSE_HPP
-#define NSL_CORE_LOGGER_RESPONSE_HPP
+#ifndef NDN_DELOREAN_CORE_LOGGER_RESPONSE_HPP
+#define NDN_DELOREAN_CORE_LOGGER_RESPONSE_HPP
#include "common.hpp"
#include "util/non-negative-integer.hpp"
@@ -95,4 +95,4 @@
} // namespace nsl
-#endif // NSL_CORE_LOGGER_RESPONSE_HPP
+#endif // NDN_DELOREAN_CORE_LOGGER_RESPONSE_HPP
diff --git a/core/logger.cpp b/core/logger.cpp
index 6a1e67c..2089e2a 100644
--- a/core/logger.cpp
+++ b/core/logger.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "logger.hpp"
diff --git a/core/merkle-tree.cpp b/core/merkle-tree.cpp
index a579350..fa9dd2c 100644
--- a/core/merkle-tree.cpp
+++ b/core/merkle-tree.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "merkle-tree.hpp"
diff --git a/core/merkle-tree.hpp b/core/merkle-tree.hpp
index 3e877f1..f1baa46 100644
--- a/core/merkle-tree.hpp
+++ b/core/merkle-tree.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_MERKLE_TREE_HPP
-#define NSL_CORE_MERKLE_TREE_HPP
+#ifndef NDN_DELOREAN_CORE_MERKLE_TREE_HPP
+#define NDN_DELOREAN_CORE_MERKLE_TREE_HPP
#include "common.hpp"
#include "db.hpp"
@@ -105,4 +105,4 @@
}// namespace nsl
-#endif // NSL_CORE_MERKLE_TREE_HPP
+#endif // NDN_DELOREAN_CORE_MERKLE_TREE_HPP
diff --git a/core/node.cpp b/core/node.cpp
index 11e1cd0..d0882e4 100644
--- a/core/node.cpp
+++ b/core/node.cpp
@@ -1,23 +1,24 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
+
#include "node.hpp"
#include <ndn-cxx/util/digest.hpp>
diff --git a/core/node.hpp b/core/node.hpp
index c3d0572..a9cb487 100644
--- a/core/node.hpp
+++ b/core/node.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_NODE_HPP
-#define NSL_CORE_NODE_HPP
+#ifndef NDN_DELOREAN_CORE_NODE_HPP
+#define NDN_DELOREAN_CORE_NODE_HPP
#include "common.hpp"
#include "util/non-negative-integer.hpp"
@@ -121,4 +121,4 @@
} // namespace nsl
-#endif // NSL_CORE_NODE_HPP
+#endif // NDN_DELOREAN_CORE_NODE_HPP
diff --git a/core/policy-checker.cpp b/core/policy-checker.cpp
index b0d6531..97464a1 100644
--- a/core/policy-checker.cpp
+++ b/core/policy-checker.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "policy-checker.hpp"
diff --git a/core/policy-checker.hpp b/core/policy-checker.hpp
index 8eea548..1194316 100644
--- a/core/policy-checker.hpp
+++ b/core/policy-checker.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_POLICY_CHECKER_HPP
-#define NSL_CORE_POLICY_CHECKER_HPP
+#ifndef NDN_DELOREAN_CORE_POLICY_CHECKER_HPP
+#define NDN_DELOREAN_CORE_POLICY_CHECKER_HPP
#include "common.hpp"
#include "db.hpp"
@@ -73,4 +73,4 @@
} // namespace nsl
-#endif // NSL_CORE_POLICY_CHECKER_HPP
+#endif // NDN_DELOREAN_CORE_POLICY_CHECKER_HPP
diff --git a/core/sub-tree-binary.cpp b/core/sub-tree-binary.cpp
index be9c2d3..26cef84 100644
--- a/core/sub-tree-binary.cpp
+++ b/core/sub-tree-binary.cpp
@@ -1,22 +1,22 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
#include "sub-tree-binary.hpp"
diff --git a/core/tlv.hpp b/core/tlv.hpp
index 56de322..d36f772 100644
--- a/core/tlv.hpp
+++ b/core/tlv.hpp
@@ -1,27 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-
-#ifndef NSL_CORE_TLV_HPP
-#define NSL_CORE_TLV_HPP
+#ifndef NDN_DELOREAN_CORE_TLV_HPP
+#define NDN_DELOREAN_CORE_TLV_HPP
namespace nsl {
namespace tlv {
@@ -50,4 +49,4 @@
} // namespace tlv
} // namespace nsl
-#endif // NSL_CORE_TLV_HPP
+#endif // NDN_DELOREAN_CORE_TLV_HPP
diff --git a/core/util/non-negative-integer.hpp b/core/util/non-negative-integer.hpp
index eecef0f..08afe34 100644
--- a/core/util/non-negative-integer.hpp
+++ b/core/util/non-negative-integer.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_UTIL_NON_NEGATIVE_INTEGER_HPP
-#define NSL_UTIL_NON_NEGATIVE_INTEGER_HPP
+#ifndef NDN_DELOREAN_UTIL_NON_NEGATIVE_INTEGER_HPP
+#define NDN_DELOREAN_UTIL_NON_NEGATIVE_INTEGER_HPP
namespace nsl {
@@ -28,4 +28,4 @@
} // namespace nsl
-#endif // NSL_UTIL_NON_NEGATIVE_INTEGER_HPP
+#endif // NDN_DELOREAN_UTIL_NON_NEGATIVE_INTEGER_HPP
diff --git a/core/util/timestamp.hpp b/core/util/timestamp.hpp
index a955e1c..a35a09d 100644
--- a/core/util/timestamp.hpp
+++ b/core/util/timestamp.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_UTIL_TIMESTAMP_HPP
-#define NSL_UTIL_TIMESTAMP_HPP
+#ifndef NDN_DELOREAN_UTIL_TIMESTAMP_HPP
+#define NDN_DELOREAN_UTIL_TIMESTAMP_HPP
namespace nsl {
@@ -28,4 +28,4 @@
} // namespace nsl
-#endif // NSL_UTIL_TIMESTAMP_HPP
+#endif // NDN_DELOREAN_UTIL_TIMESTAMP_HPP
diff --git a/core/auditor.hpp b/core/auditor.hpp
index 9117d5d..87e67b5 100644
--- a/core/auditor.hpp
+++ b/core/auditor.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
* This file is part of NSL (NDN Signature Logger).
* See AUTHORS.md for complete list of NSL authors and contributors.
*
* NSL is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
* NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_AUDITOR_HPP
-#define NSL_CORE_AUDITOR_HPP
+#ifndef NDN_DELOREAN_CORE_AUDITOR_HPP
+#define NDN_DELOREAN_CORE_AUDITOR_HPP
#include "common.hpp"
#include "node.hpp"
@@ -50,7 +50,7 @@
const std::vector<shared_ptr<Data>>& proofs,
const Name& loggerName);
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
static bool
loadProof(std::map<Node::Index, ConstSubTreeBinaryPtr>& trees,
const std::vector<shared_ptr<Data>>& proofs,
@@ -59,4 +59,4 @@
} // namespace nsl
-#endif // NSL_CORE_AUDITOR_HPP
+#endif // NDN_DELOREAN_CORE_AUDITOR_HPP
@@ -1,26 +1,26 @@
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
@@ -1,26 +1,26 @@
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
@@ -1,26 +1,26 @@
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
diff --git a/core/db.hpp b/core/db.hpp
index 503b562..b722efe 100644
--- a/core/db.hpp
+++ b/core/db.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
* This file is part of NSL (NDN Signature Logger).
* See AUTHORS.md for complete list of NSL authors and contributors.
*
* NSL is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
* NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_DB_HPP
-#define NSL_CORE_DB_HPP
+#ifndef NDN_DELOREAN_CORE_DB_HPP
+#define NDN_DELOREAN_CORE_DB_HPP
#include "common.hpp"
#include "leaf.hpp"
@@ -69,7 +69,7 @@
std::pair<shared_ptr<Leaf>, shared_ptr<Data>>
getLeaf(const NonNegativeInteger& seqNo);
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
const NonNegativeInteger&
getMaxLeafSeq();
@@ -81,4 +81,4 @@
} // namespace nsl
-#endif // NSL_CORE_DB_HPP
+#endif // NDN_DELOREAN_CORE_DB_HPP
@@ -1,26 +1,26 @@
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
@@ -1,26 +1,26 @@
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
@@ -1,26 +1,26 @@
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
diff --git a/core/leaf.hpp b/core/leaf.hpp
index 3f8b0a5..4ee11d3 100644
--- a/core/leaf.hpp
+++ b/core/leaf.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
* This file is part of NSL (NDN Signature Logger).
* See AUTHORS.md for complete list of NSL authors and contributors.
*
* NSL is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
* NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_LEAF_HPP
-#define NSL_CORE_LEAF_HPP
+#ifndef NDN_DELOREAN_CORE_LEAF_HPP
+#define NDN_DELOREAN_CORE_LEAF_HPP
#include "common.hpp"
#include "util/non-negative-integer.hpp"
@@ -105,7 +105,7 @@
void
decode(const Data& data);
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
/// @brief Encode to a wire format or estimate wire format
template<ndn::encoding::Tag TAG>
size_t
@@ -122,7 +122,7 @@
public:
static const Name EMPTY_NAME;
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
static const size_t N_LOGGER_LEAF_SUFFIX;
static const ssize_t OFFSET_LEAF_SEQNO;
static const ssize_t OFFSET_LEAF_HASH;
@@ -140,4 +140,4 @@
} // namespace nsl
-#endif // NSL_CORE_LEAF_HPP
+#endif // NDN_DELOREAN_CORE_LEAF_HPP
@@ -1,26 +1,26 @@
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
@@ -1,26 +1,26 @@
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
@@ -1,26 +1,26 @@
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
diff --git a/core/logger.hpp b/core/logger.hpp
index a53b0aa..f685495 100644
--- a/core/logger.hpp
+++ b/core/logger.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
* This file is part of NSL (NDN Signature Logger).
* See AUTHORS.md for complete list of NSL authors and contributors.
*
* NSL is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
* NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_LOGGER_HPP
-#define NSL_CORE_LOGGER_HPP
+#ifndef NDN_DELOREAN_CORE_LOGGER_HPP
+#define NDN_DELOREAN_CORE_LOGGER_HPP
#include "common.hpp"
#include "logger-response.hpp"
@@ -53,7 +53,7 @@
NonNegativeInteger
addSelfSignedCert(ndn::IdentityCertificate& cert, const Timestamp& timestamp);
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
void
initializeKeys();
@@ -137,4 +137,4 @@
} // namespace nsl
-#endif // NSL_CORE_LOGGER_HPP
+#endif // NDN_DELOREAN_CORE_LOGGER_HPP
@@ -1,26 +1,26 @@
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
@@ -1,26 +1,26 @@
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
@@ -1,26 +1,26 @@
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
diff --git a/core/sub-tree-binary.hpp b/core/sub-tree-binary.hpp
index 15a0e3e..ba52e1b 100644
--- a/core/sub-tree-binary.hpp
+++ b/core/sub-tree-binary.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
* This file is part of NSL (NDN Signature Logger).
* See AUTHORS.md for complete list of NSL authors and contributors.
*
* NSL is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
* NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_SUB_TREE_HPP
-#define NSL_CORE_SUB_TREE_HPP
+#ifndef NDN_DELOREAN_CORE_SUB_TREE_HPP
+#define NDN_DELOREAN_CORE_SUB_TREE_HPP
#include "node.hpp"
@@ -148,7 +148,7 @@
public:
static const size_t SUB_TREE_DEPTH;
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
static const time::milliseconds INCOMPLETE_FRESHNESS_PERIOD;
static const std::string COMPONENT_COMPLETE;
static const ssize_t OFFSET_ROOTHASH;
@@ -179,4 +179,4 @@
} // namespace nsl
-#endif // NSL_CORE_SUB_TREE_HPP
+#endif // NDN_DELOREAN_CORE_SUB_TREE_HPP
@@ -1,26 +1,26 @@
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
@@ -1,26 +1,26 @@
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
@@ -1,26 +1,26 @@
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*